/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#define PLATFORM "windows"

#ifndef PLATFORM_WINDOWS
  #define PLATFORM_WINDOWS
#endif

#pragma warning( disable : 4675 )
#pragma warning( disable : 4503 )

#define finline __forceinline

//define SEQAN_SWITCH_USE_FORWARDS to use generated forwards 
//#define SEQAN_SWITCH_USE_FORWARDS
